reorderable_tree_list_view library

Classes

ActivateNodeAction
Action that handles activating tree nodes.
ActivateNodeIntent
Intent to activate a tree node.
CollapseNodeAction
Action that handles collapsing tree nodes.
CollapseNodeIntent
Intent to collapse a tree node.
CopyNodeAction
Action that handles copying tree nodes.
CopyNodeIntent
Intent to copy a tree node.
DeleteNodeAction
Action that handles deleting tree nodes.
DeleteNodeIntent
Intent to delete a tree node.
ExpandNodeAction
Action that handles expanding tree nodes.
ExpandNodeIntent
Intent to expand a tree node.
MoveNodeAction
Action that handles moving tree nodes.
MoveNodeIntent
Intent to move a tree node.
PasteNodeAction
Action that handles pasting tree nodes.
PasteNodeIntent
Intent to paste copied nodes.
ReorderableTreeListView
A reorderable list view that displays hierarchical tree data.
ReorderableTreeListViewItem
A widget that wraps content for display in a ReorderableTreeListView.
SelectNodeAction
Action that handles selecting tree nodes.
SelectNodeIntent
Intent to select a tree node.
TreeBuilder
Builds a complete tree structure from a sparse list of URI paths.
TreeCollapseAllAction
Action that collapses all nodes in the tree view.
TreeCollapseAllIntent
Intent to collapse all tree nodes.
TreeCopyAction
Action that copies the currently selected tree nodes.
TreeCopyIntent
Intent to copy the currently selected tree nodes.
TreeDeleteAction
Action that deletes the currently selected tree nodes.
TreeDeleteIntent
Intent to delete the currently selected tree nodes.
TreeExpandAllAction
Action that expands all nodes in the tree view.
TreeExpandAllIntent
Intent to expand all tree nodes.
TreeNode
Represents a node in the tree structure.
TreePasteAction
Action that pastes copied nodes at the current location.
TreePasteIntent
Intent to paste copied nodes at the current location.
TreePath
Utility class for working with URI paths in the tree structure.
TreeSelectAllAction
Action that selects all visible nodes in the tree view.
TreeSelectAllIntent
Intent to select all tree nodes.
TreeState
Manages the state of a tree structure.
TreeTheme
Theme configuration for the tree list view.
TreeThemeData
An InheritedWidget that provides a TreeTheme to its descendants.
TreeViewAction<T extends Intent>
Base class for all tree view actions.
TreeViewShortcuts
A widget that provides default keyboard shortcuts for tree view operations.

Enums

SelectionMode
Defines how items can be selected in the tree view.

Typedefs

TreeCanDragAsyncCallback = Future<bool> Function(Uri path)
Async callback to determine if a node can be dragged.
TreeCanDragCallback = bool Function(Uri path)
Callback to determine if a node can be dragged.
TreeCanDropAsyncCallback = Future<bool> Function(Uri draggedPath, Uri targetPath)
Async callback to determine if a drop is allowed.
TreeCanDropCallback = bool Function(Uri draggedPath, Uri targetPath)
Callback to determine if a drop is allowed.
TreeCanExpandAsyncCallback = Future<bool> Function(Uri path)
Async callback to determine if a node can be expanded.
TreeCanExpandCallback = bool Function(Uri path)
Callback to determine if a node can be expanded.
TreeContextMenuCallback = void Function(Uri path, Offset globalPosition)
Callback for context menu events.
TreeDragEndCallback = void Function(Uri path)
Callback for drag end events.
TreeDragStartCallback = void Function(Uri path)
Callback for drag start events.
TreeExpandCallback = void Function(Uri path)
Callback for expansion-related events.
TreeItemActivatedCallback = void Function(Uri path)
Callback for item activation events.
TreeItemTapCallback = void Function(Uri path)
Callback for item tap events.
TreeReorderCallback = void Function(Uri oldPath, Uri newPath)
Callback for reorder events.
TreeSelectionChangedCallback = void Function(Set<Uri> selection)
Callback for selection change events.